<?php
/**
 * Email Order Items
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/email-order-items.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you (the theme developer) will need
 * to copy the new files to your theme to maintain compatibility. We try to do this as little as possible, but it does happen.
 *
 * @see     https://woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates\Emails
 * @version 7.8.0
 */

defined( 'ABSPATH' ) || exit;

foreach ( $items as $item_id => $item ) :
	$product = $item->get_product();

	if ( ! apply_filters( 'woocommerce_order_item_visible', true, $item ) ) {
		continue;
	}
	?>
	<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_email_order_item_class', 'order_item', $item, $order, $plain_text ) ); ?>">
		<?php
		// PRODUCT COLUMN - ANCHO 60%
		?>
		<td class="td font-family text-align-left" width="60%" style="vertical-align: middle; word-wrap:break-word;">
			<?php
			// Show title/image etc.
			do_action( 'woocommerce_email_before_order_item_name', $item, $sent_to_admin, $plain_text, $email );

			echo wp_kses_post( $item->get_name() );

			if ( $show_sku && is_object( $product ) && $product->get_sku() ) {
				echo wp_kses_post( ' (#' . $product->get_sku() . ')' );
			}

			if ( is_object( $product ) && $product->is_downloadable() && $order->is_download_permitted() ) {
				$downloads = $item->get_item_downloads();
				$i         = 0;
				foreach ( $downloads as $download ) {
					$i++;
					echo '<br/><a href="' . esc_url( $download['download_url'] ) . '" class="woocommerce-download-link">' .
						esc_html( sprintf( __( 'Download file %d', 'woocommerce' ), $i ) ) . '</a>';
				}
			}

			// Allow other plugins to add additional product information here.
			do_action( 'woocommerce_order_item_meta_start', $item_id, $item, $order, $plain_text );

			wc_display_item_meta( $item ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

			// Allow other plugins to add additional product information here.
			do_action( 'woocommerce_order_item_meta_end', $item_id, $item, $order, $plain_text );
			?>
		</td>

		<?php
		// CANTIDAD COLUMN - ANCHO 20%
		?>
		<td class="td font-family" width="20%" style="vertical-align:middle;">
			<?php
			echo esc_html( apply_filters( 'woocommerce_email_order_item_quantity', $item->get_quantity(), $item ) );
			?>
		</td>

		<?php
		// PRECIO COLUMN - ANCHO 20%
		?>
		<td class="td font-family text-align-<?php echo esc_attr( $price_text_align ); ?>" width="20%" style="vertical-align:middle;">
			<?php
			echo wp_kses_post( $order->get_formatted_line_subtotal( $item ) );
			?>
		</td>
	</tr>
	<?php

	if ( $show_purchase_note && $purchase_note ) {
		?>
		<tr>
			<td colspan="3" class="td font-family" style="vertical-align:middle;">
				<?php
				echo wp_kses_post( wpautop( do_shortcode( $purchase_note ) ) );
				?>
			</td>
		</tr>
		<?php
	}
	?>

<?php endforeach; ?>